import { TailwindPluginHelpers } from '../TailwindPlugin/TailwindPluginHelpers';
/**
 * Available spacing types.
 * Exported as a type instead of enum for JavaScript convenience.
 *
 * @export
 * @type {SpacingType}
 */
export declare type SpacingType = 'margin' | 'padding';
/**
 * Available spacing directions.
 *
 * @export
 * @enum {number}
 */
export declare enum SpacingDirection {
    Top = "top",
    Bottom = "bottom",
    Left = "left",
    Right = "right",
    Vertical = "y",
    Horizontal = "x"
}
/**
 * Gets the spacing property name for a given property and direction.
 *
 * @export
 * @param {string} property
 * @param {SpacingDirection} direction
 * @returns
 */
export declare function getSpacingPropertyName(property: string, direction: SpacingDirection): string;
/**
 * Add spacing utilities to Tailwind.
 *
 * @export
 * @param {SpacingType} type The type of spacing.
 * @param {string} property The property that applies the spacing.
 * @param {string} shortname The short name for utility classes names.
 * @param {TailwindPluginHelpers} { e, theme, variants, addUtilities }
 */
export default function (type: SpacingType, shortname: string, property: string, { e, theme, variants, addUtilities }: TailwindPluginHelpers): void;
export declare function getConfigType(type: SpacingType, theme: any): any;
export declare const negativeSpacingConfig: (theme: any) => any;
export declare const spacingConfig: (theme: any) => any;
